@@ -21,8 +21,9 @@ class TerminalColorMap:
     return (minDiffAnsi, self.colors[minDiffAnsi])
 
   def colorize(self, string, rgb=None, ansi=None,bg=None,ansi_bg=None):
+    '''Returns the colored string'''
     if not isinstance(string,str):
-        raise TerminalColorMapException('String is not of <str> type')
+        string = str(string)
     if rgb is None and ansi is None:
       raise TerminalColorMapException('colorize: must specify one named parameter: rgb or ansi')
     if rgb is not None and ansi is not None:
